@@ -148,13 +148,13 @@ class PDFImageDraw(base.ImageDraw):
 
             if angle == 90:
                 box = Box(-box.y2, box.x1, -box.y1, box.x1 + box.width)
-                box = box.shift(x=self.size.y, y=self.size.y)
+                box = box.shift(x=self.size.height, y=self.size.height)
             elif angle == 180:
                 box = Box(-box.x2, -box.y2, -box.x1, -box.y2 + box.height)
-                box = box.shift(y=self.size.y * 2)
+                box = box.shift(y=self.size.height * 2)
             elif angle == 270:
                 box = Box(box.y1, -box.x2, box.y2, -box.x1)
-                box = box.shift(x=-self.size.y, y=self.size.y)
+                box = box.shift(x=-self.size.height, y=self.size.height)
 
         self.set_font(font)
         lines = self.textfolder(box, string, font, **kwargs)
@@ -215,10 +215,13 @@ class PDFImageDraw(base.ImageDraw):
     def image(self, box, url):
         try:
             image = images.open(url, mode='pillow')
-            url = ImageReader(image)
+            if image.mode not in ('RGBA', 'L', 'RGB', 'CYMYK'):
+                # convert to format that reportlab can recognize
+                image = image.convert('RGBA')
 
             y = self.size[1] - box[3]
-            self.canvas.drawImage(url, box.x1, y, box.width, box.height,
+            data = ImageReader(image)
+            self.canvas.drawImage(data, box.x1, y, box.width, box.height,
                                   mask='auto', preserveAspectRatio=True)
         except IOError:
             pass
